==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas las fuentes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activas</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chino</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monoespaciado</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>% 1 es una familia de fuentes, si continúa, se eliminarán todas las fuentes.</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>% 1 es una familia de fuentes, si continúa, se habilitarán todas las fuentes.</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>% 1 es una familia de fuentes, si continúa, se deshabilitarán todas las fuentes.</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Habilitar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Deshabilitar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Aplicar a todas las familias de fuentes seleccionadas</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Archivo roto</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>La misma versión está instalada</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fuente del sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl + Mayús + /</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>AvPág</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>RePág</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl + Alt + F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl + F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl + O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl + =</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl + -</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl + 0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fuente instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fuentes instaladas</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Error al instalar la fuente %1. No hay suficiente espacio en disco.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Error al instalar las fuentes %1. No hay suficiente espacio en disco.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">Archivo roto</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fuente no estará disponible para las aplicaciones</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estas fuentes no estarán disponibles para las aplicaciones</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Las otras fuentes del sistema %1 no pueden ser borradas</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La fuente «%1» está en uso no puede ser eliminada</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Las otras %1 fuentes del sistema y la fuente «%2» está en uso, no pueden ser borradas</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>¿Está seguro de que quieres borrar la(s) fuente(s) %1?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Borrando fuentes, por favor, espere...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificación de fuente</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>No hay fuentes para instalar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Salir</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Continuar</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nombre completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nombre PostScript</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Administrador de fuentes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Administrador de fuentes de Deepin ayuda a instalar y gestionar fuentes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Cargando fuentes, por favor espere…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Fuente exportada al escritorio</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fuentes exportadas al escritorio</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>La instalación de la fuente falló. El espacio en el disco es insuficiente.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>La exportación de %1 fuentes falló. El espacio en el disco es insuficiente.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Añadir fuente</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilitar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deshabilitar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritas</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivado</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Las fuentes han sido desactivadas</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 está en uso, por lo que no se puede desactivar</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>No se pueden desactivar las fuentes del sistema y las fuentes en uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>No se pueden desactivar las fuentes del sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar la fuente</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Archivo roto</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalada</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>No instalada</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar la fuente</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No hay resultados de la búsqueda</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Sin fuentes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Página arriba</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Página abajo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Añadir fuente</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritas</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Información de la fuente</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Introducir texto de vista previa</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas las fuentes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activas</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chino</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monoespaciado</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 es una familia de fuentes, si continúa, se eliminarán todas las fuentes.</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 es una familia de fuentes, si continúa, se habilitarán todas las fuentes.</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 es una familia de fuentes, si continúa, se deshabilitarán todas las fuentes.</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Habilitar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Deshabilitar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Aplicar a todas las familias de fuentes seleccionadas</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Archivo roto</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>La misma versión está instalada</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fuente del sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl + Mayús + /</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>AvPág</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>RePág</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl + Alt + F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl + F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl + O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl + =</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl + -</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl + 0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fuente instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fuentes instaladas</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Error al instalar la fuente %1. No hay suficiente espacio en disco.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Error al instalar las fuentes %1. No hay suficiente espacio en disco.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Fuentes</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Archivo roto</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fuente no estará disponible para las aplicaciones</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estas fuentes no estarán disponibles para las aplicaciones</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Las otras fuentes del sistema %1 no pueden ser borradas</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La fuente «%1» está en uso no puede ser eliminada</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Las otras %1 fuentes del sistema y la fuente «%2» está en uso, no pueden ser borradas</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>¿Está seguro de que quiere borrar la(s) fuente(s) %1?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Borrando fuentes, por favor, espere...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificación de fuente</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>No hay fuentes para instalar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>No dejes que tus sueños sean sueños</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nombre completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nombre PostScript</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Derechos de autor</translation>
    </message>
    <message>
        <source>License Description</source>
        <translation>Descripción de la licencia</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Administrador de fuentes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Administrador de fuentes de Deepin ayuda a instalar y gestionar fuentes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Cargando fuentes, por favor espere…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Fuente exportada al escritorio</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fuentes exportadas al escritorio</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>La instalación de la fuente falló. El espacio en el disco es insuficiente.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>La exportación de %1 fuentes falló. El espacio en el disco es insuficiente.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Añadir fuente</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilitar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deshabilitar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritas</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivado</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Las fuentes han sido desactivadas</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 está en uso, por lo que no se puede desactivar</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>No se pueden desactivar las fuentes del sistema y las fuentes en uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>No se pueden desactivar las fuentes del sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar la fuente</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Archivo roto</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalada</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>No instalada</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar la fuente</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No hay resultados de la búsqueda</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Sin fuentes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Página arriba</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Página abajo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Añadir fuente</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritas</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Información de la fuente</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Introducir texto de vista previa</translation>
    </message>
</context>
</TS>
